gapipy.resources.tour package
=============================

Submodules
----------

gapipy.resources.tour.accommodation module
------------------------------------------

.. automodule:: gapipy.resources.tour.accommodation
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.activity module
-------------------------------------

.. automodule:: gapipy.resources.tour.activity
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.departure module
--------------------------------------

.. automodule:: gapipy.resources.tour.departure
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.promotion module
--------------------------------------

.. automodule:: gapipy.resources.tour.promotion
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.single_supplement module
----------------------------------------------

.. automodule:: gapipy.resources.tour.single_supplement
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.tour module
---------------------------------

.. automodule:: gapipy.resources.tour.tour
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.tour_category module
------------------------------------------

.. automodule:: gapipy.resources.tour.tour_category
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.tour_dossier module
-----------------------------------------

.. automodule:: gapipy.resources.tour.tour_dossier
    :members:
    :undoc-members:
    :show-inheritance:

gapipy.resources.tour.transport module
--------------------------------------

.. automodule:: gapipy.resources.tour.transport
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gapipy.resources.tour
    :members:
    :undoc-members:
    :show-inheritance:
